pub struct LEAdvertisementProperties { /* private fields */ }Implementations
Sourceimpl LEAdvertisementProperties
impl LEAdvertisementProperties
Sourcepub async fn type_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn type_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Type property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn local_name_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn local_name_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
LocalName property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn service_uuids_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn service_uuids_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
ServiceUuids property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn solicit_uuids_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn solicit_uuids_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
SolicitUuids property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn manufacturer_data_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn manufacturer_data_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
ManufacturerData property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn service_data_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn service_data_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
ServiceData property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn data_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn data_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Data property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn discoverable_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn discoverable_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Discoverable property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn discoverable_timeout_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn discoverable_timeout_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
DiscoverableTimeout property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn includes_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn includes_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Includes property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn duration_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn duration_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Duration property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn timeout_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn timeout_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Timeout property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn min_interval_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn min_interval_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
MinInterval property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn max_interval_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn max_interval_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
MaxInterval property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn tx_power_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn tx_power_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
TxPower property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn appearance_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn appearance_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
Appearance property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn secondary_channel_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn secondary_channel_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
SecondaryChannel property.
This method should be called if a property value changes outside its setter method.